@@ -200,7 +200,7 @@ constructOrientableOrientation val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data OrientableOrientationPropertyInfo
 instance AttrInfo OrientableOrientationPropertyInfo where
-    type AttrAllowedOps OrientableOrientationPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps OrientableOrientationPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint OrientableOrientationPropertyInfo = IsOrientable
     type AttrSetTypeConstraint OrientableOrientationPropertyInfo = (~) Gtk.Enums.Orientation
     type AttrTransferTypeConstraint OrientableOrientationPropertyInfo = (~) Gtk.Enums.Orientation
@@ -210,6 +210,7 @@ instance AttrInfo OrientableOrientationPropertyInfo where
     type AttrOrigin OrientableOrientationPropertyInfo = Orientable
     attrGet = getOrientableOrientation
     attrSet = setOrientableOrientation
+    attrPut = setOrientableOrientation
     attrTransfer _ v = do
         return v
     attrConstruct = constructOrientableOrientation
