@@ -466,6 +466,7 @@ instance AttrInfo ColumnViewCellChildPropertyInfo where
     type AttrOrigin ColumnViewCellChildPropertyInfo = ColumnViewCell
     attrGet = getColumnViewCellChild
     attrSet = setColumnViewCellChild
+    attrPut = undefined
     attrTransfer _ v = do
         unsafeCastTo Gtk.Widget.Widget v
     attrConstruct = constructColumnViewCellChild
@@ -508,7 +509,7 @@ constructColumnViewCellFocusable val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data ColumnViewCellFocusablePropertyInfo
 instance AttrInfo ColumnViewCellFocusablePropertyInfo where
-    type AttrAllowedOps ColumnViewCellFocusablePropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps ColumnViewCellFocusablePropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint ColumnViewCellFocusablePropertyInfo = IsColumnViewCell
     type AttrSetTypeConstraint ColumnViewCellFocusablePropertyInfo = (~) Bool
     type AttrTransferTypeConstraint ColumnViewCellFocusablePropertyInfo = (~) Bool
@@ -518,6 +519,7 @@ instance AttrInfo ColumnViewCellFocusablePropertyInfo where
     type AttrOrigin ColumnViewCellFocusablePropertyInfo = ColumnViewCell
     attrGet = getColumnViewCellFocusable
     attrSet = setColumnViewCellFocusable
+    attrPut = setColumnViewCellFocusable
     attrTransfer _ v = do
         return v
     attrConstruct = constructColumnViewCellFocusable
@@ -555,6 +557,7 @@ instance AttrInfo ColumnViewCellItemPropertyInfo where
     type AttrOrigin ColumnViewCellItemPropertyInfo = ColumnViewCell
     attrGet = getColumnViewCellItem
     attrSet = undefined
+    attrPut = undefined
     attrTransfer _ = undefined
     attrConstruct = undefined
     attrClear = undefined
@@ -591,6 +594,7 @@ instance AttrInfo ColumnViewCellPositionPropertyInfo where
     type AttrOrigin ColumnViewCellPositionPropertyInfo = ColumnViewCell
     attrGet = getColumnViewCellPosition
     attrSet = undefined
+    attrPut = undefined
     attrTransfer _ = undefined
     attrConstruct = undefined
     attrClear = undefined
@@ -627,6 +631,7 @@ instance AttrInfo ColumnViewCellSelectedPropertyInfo where
     type AttrOrigin ColumnViewCellSelectedPropertyInfo = ColumnViewCell
     attrGet = getColumnViewCellSelected
     attrSet = undefined
+    attrPut = undefined
     attrTransfer _ = undefined
     attrConstruct = undefined
     attrClear = undefined
