@@ -450,7 +450,7 @@ constructColumnViewRowAccessibleDescription val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data ColumnViewRowAccessibleDescriptionPropertyInfo
 instance AttrInfo ColumnViewRowAccessibleDescriptionPropertyInfo where
-    type AttrAllowedOps ColumnViewRowAccessibleDescriptionPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps ColumnViewRowAccessibleDescriptionPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint ColumnViewRowAccessibleDescriptionPropertyInfo = IsColumnViewRow
     type AttrSetTypeConstraint ColumnViewRowAccessibleDescriptionPropertyInfo = (~) T.Text
     type AttrTransferTypeConstraint ColumnViewRowAccessibleDescriptionPropertyInfo = (~) T.Text
@@ -460,6 +460,7 @@ instance AttrInfo ColumnViewRowAccessibleDescriptionPropertyInfo where
     type AttrOrigin ColumnViewRowAccessibleDescriptionPropertyInfo = ColumnViewRow
     attrGet = getColumnViewRowAccessibleDescription
     attrSet = setColumnViewRowAccessibleDescription
+    attrPut = setColumnViewRowAccessibleDescription
     attrTransfer _ v = do
         return v
     attrConstruct = constructColumnViewRowAccessibleDescription
@@ -502,7 +503,7 @@ constructColumnViewRowAccessibleLabel val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data ColumnViewRowAccessibleLabelPropertyInfo
 instance AttrInfo ColumnViewRowAccessibleLabelPropertyInfo where
-    type AttrAllowedOps ColumnViewRowAccessibleLabelPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps ColumnViewRowAccessibleLabelPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint ColumnViewRowAccessibleLabelPropertyInfo = IsColumnViewRow
     type AttrSetTypeConstraint ColumnViewRowAccessibleLabelPropertyInfo = (~) T.Text
     type AttrTransferTypeConstraint ColumnViewRowAccessibleLabelPropertyInfo = (~) T.Text
@@ -512,6 +513,7 @@ instance AttrInfo ColumnViewRowAccessibleLabelPropertyInfo where
     type AttrOrigin ColumnViewRowAccessibleLabelPropertyInfo = ColumnViewRow
     attrGet = getColumnViewRowAccessibleLabel
     attrSet = setColumnViewRowAccessibleLabel
+    attrPut = setColumnViewRowAccessibleLabel
     attrTransfer _ v = do
         return v
     attrConstruct = constructColumnViewRowAccessibleLabel
@@ -554,7 +556,7 @@ constructColumnViewRowActivatable val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data ColumnViewRowActivatablePropertyInfo
 instance AttrInfo ColumnViewRowActivatablePropertyInfo where
-    type AttrAllowedOps ColumnViewRowActivatablePropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps ColumnViewRowActivatablePropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint ColumnViewRowActivatablePropertyInfo = IsColumnViewRow
     type AttrSetTypeConstraint ColumnViewRowActivatablePropertyInfo = (~) Bool
     type AttrTransferTypeConstraint ColumnViewRowActivatablePropertyInfo = (~) Bool
@@ -564,6 +566,7 @@ instance AttrInfo ColumnViewRowActivatablePropertyInfo where
     type AttrOrigin ColumnViewRowActivatablePropertyInfo = ColumnViewRow
     attrGet = getColumnViewRowActivatable
     attrSet = setColumnViewRowActivatable
+    attrPut = setColumnViewRowActivatable
     attrTransfer _ v = do
         return v
     attrConstruct = constructColumnViewRowActivatable
@@ -606,7 +609,7 @@ constructColumnViewRowFocusable val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data ColumnViewRowFocusablePropertyInfo
 instance AttrInfo ColumnViewRowFocusablePropertyInfo where
-    type AttrAllowedOps ColumnViewRowFocusablePropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps ColumnViewRowFocusablePropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint ColumnViewRowFocusablePropertyInfo = IsColumnViewRow
     type AttrSetTypeConstraint ColumnViewRowFocusablePropertyInfo = (~) Bool
     type AttrTransferTypeConstraint ColumnViewRowFocusablePropertyInfo = (~) Bool
@@ -616,6 +619,7 @@ instance AttrInfo ColumnViewRowFocusablePropertyInfo where
     type AttrOrigin ColumnViewRowFocusablePropertyInfo = ColumnViewRow
     attrGet = getColumnViewRowFocusable
     attrSet = setColumnViewRowFocusable
+    attrPut = setColumnViewRowFocusable
     attrTransfer _ v = do
         return v
     attrConstruct = constructColumnViewRowFocusable
@@ -653,6 +657,7 @@ instance AttrInfo ColumnViewRowItemPropertyInfo where
     type AttrOrigin ColumnViewRowItemPropertyInfo = ColumnViewRow
     attrGet = getColumnViewRowItem
     attrSet = undefined
+    attrPut = undefined
     attrTransfer _ = undefined
     attrConstruct = undefined
     attrClear = undefined
@@ -689,6 +694,7 @@ instance AttrInfo ColumnViewRowPositionPropertyInfo where
     type AttrOrigin ColumnViewRowPositionPropertyInfo = ColumnViewRow
     attrGet = getColumnViewRowPosition
     attrSet = undefined
+    attrPut = undefined
     attrTransfer _ = undefined
     attrConstruct = undefined
     attrClear = undefined
@@ -730,7 +736,7 @@ constructColumnViewRowSelectable val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data ColumnViewRowSelectablePropertyInfo
 instance AttrInfo ColumnViewRowSelectablePropertyInfo where
-    type AttrAllowedOps ColumnViewRowSelectablePropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps ColumnViewRowSelectablePropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint ColumnViewRowSelectablePropertyInfo = IsColumnViewRow
     type AttrSetTypeConstraint ColumnViewRowSelectablePropertyInfo = (~) Bool
     type AttrTransferTypeConstraint ColumnViewRowSelectablePropertyInfo = (~) Bool
@@ -740,6 +746,7 @@ instance AttrInfo ColumnViewRowSelectablePropertyInfo where
     type AttrOrigin ColumnViewRowSelectablePropertyInfo = ColumnViewRow
     attrGet = getColumnViewRowSelectable
     attrSet = setColumnViewRowSelectable
+    attrPut = setColumnViewRowSelectable
     attrTransfer _ v = do
         return v
     attrConstruct = constructColumnViewRowSelectable
@@ -777,6 +784,7 @@ instance AttrInfo ColumnViewRowSelectedPropertyInfo where
     type AttrOrigin ColumnViewRowSelectedPropertyInfo = ColumnViewRow
     attrGet = getColumnViewRowSelected
     attrSet = undefined
+    attrPut = undefined
     attrTransfer _ = undefined
     attrConstruct = undefined
     attrClear = undefined
