@@ -429,7 +429,7 @@ constructConstraintGuideMaxHeight val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data ConstraintGuideMaxHeightPropertyInfo
 instance AttrInfo ConstraintGuideMaxHeightPropertyInfo where
-    type AttrAllowedOps ConstraintGuideMaxHeightPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps ConstraintGuideMaxHeightPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint ConstraintGuideMaxHeightPropertyInfo = IsConstraintGuide
     type AttrSetTypeConstraint ConstraintGuideMaxHeightPropertyInfo = (~) Int32
     type AttrTransferTypeConstraint ConstraintGuideMaxHeightPropertyInfo = (~) Int32
@@ -439,6 +439,7 @@ instance AttrInfo ConstraintGuideMaxHeightPropertyInfo where
     type AttrOrigin ConstraintGuideMaxHeightPropertyInfo = ConstraintGuide
     attrGet = getConstraintGuideMaxHeight
     attrSet = setConstraintGuideMaxHeight
+    attrPut = setConstraintGuideMaxHeight
     attrTransfer _ v = do
         return v
     attrConstruct = constructConstraintGuideMaxHeight
@@ -481,7 +482,7 @@ constructConstraintGuideMaxWidth val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data ConstraintGuideMaxWidthPropertyInfo
 instance AttrInfo ConstraintGuideMaxWidthPropertyInfo where
-    type AttrAllowedOps ConstraintGuideMaxWidthPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps ConstraintGuideMaxWidthPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint ConstraintGuideMaxWidthPropertyInfo = IsConstraintGuide
     type AttrSetTypeConstraint ConstraintGuideMaxWidthPropertyInfo = (~) Int32
     type AttrTransferTypeConstraint ConstraintGuideMaxWidthPropertyInfo = (~) Int32
@@ -491,6 +492,7 @@ instance AttrInfo ConstraintGuideMaxWidthPropertyInfo where
     type AttrOrigin ConstraintGuideMaxWidthPropertyInfo = ConstraintGuide
     attrGet = getConstraintGuideMaxWidth
     attrSet = setConstraintGuideMaxWidth
+    attrPut = setConstraintGuideMaxWidth
     attrTransfer _ v = do
         return v
     attrConstruct = constructConstraintGuideMaxWidth
@@ -533,7 +535,7 @@ constructConstraintGuideMinHeight val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data ConstraintGuideMinHeightPropertyInfo
 instance AttrInfo ConstraintGuideMinHeightPropertyInfo where
-    type AttrAllowedOps ConstraintGuideMinHeightPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps ConstraintGuideMinHeightPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint ConstraintGuideMinHeightPropertyInfo = IsConstraintGuide
     type AttrSetTypeConstraint ConstraintGuideMinHeightPropertyInfo = (~) Int32
     type AttrTransferTypeConstraint ConstraintGuideMinHeightPropertyInfo = (~) Int32
@@ -543,6 +545,7 @@ instance AttrInfo ConstraintGuideMinHeightPropertyInfo where
     type AttrOrigin ConstraintGuideMinHeightPropertyInfo = ConstraintGuide
     attrGet = getConstraintGuideMinHeight
     attrSet = setConstraintGuideMinHeight
+    attrPut = setConstraintGuideMinHeight
     attrTransfer _ v = do
         return v
     attrConstruct = constructConstraintGuideMinHeight
@@ -585,7 +588,7 @@ constructConstraintGuideMinWidth val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data ConstraintGuideMinWidthPropertyInfo
 instance AttrInfo ConstraintGuideMinWidthPropertyInfo where
-    type AttrAllowedOps ConstraintGuideMinWidthPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps ConstraintGuideMinWidthPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint ConstraintGuideMinWidthPropertyInfo = IsConstraintGuide
     type AttrSetTypeConstraint ConstraintGuideMinWidthPropertyInfo = (~) Int32
     type AttrTransferTypeConstraint ConstraintGuideMinWidthPropertyInfo = (~) Int32
@@ -595,6 +598,7 @@ instance AttrInfo ConstraintGuideMinWidthPropertyInfo where
     type AttrOrigin ConstraintGuideMinWidthPropertyInfo = ConstraintGuide
     attrGet = getConstraintGuideMinWidth
     attrSet = setConstraintGuideMinWidth
+    attrPut = setConstraintGuideMinWidth
     attrTransfer _ v = do
         return v
     attrConstruct = constructConstraintGuideMinWidth
@@ -656,6 +660,7 @@ instance AttrInfo ConstraintGuideNamePropertyInfo where
     type AttrOrigin ConstraintGuideNamePropertyInfo = ConstraintGuide
     attrGet = getConstraintGuideName
     attrSet = setConstraintGuideName
+    attrPut = undefined
     attrTransfer _ v = do
         return v
     attrConstruct = constructConstraintGuideName
@@ -698,7 +703,7 @@ constructConstraintGuideNatHeight val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data ConstraintGuideNatHeightPropertyInfo
 instance AttrInfo ConstraintGuideNatHeightPropertyInfo where
-    type AttrAllowedOps ConstraintGuideNatHeightPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps ConstraintGuideNatHeightPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint ConstraintGuideNatHeightPropertyInfo = IsConstraintGuide
     type AttrSetTypeConstraint ConstraintGuideNatHeightPropertyInfo = (~) Int32
     type AttrTransferTypeConstraint ConstraintGuideNatHeightPropertyInfo = (~) Int32
@@ -708,6 +713,7 @@ instance AttrInfo ConstraintGuideNatHeightPropertyInfo where
     type AttrOrigin ConstraintGuideNatHeightPropertyInfo = ConstraintGuide
     attrGet = getConstraintGuideNatHeight
     attrSet = setConstraintGuideNatHeight
+    attrPut = setConstraintGuideNatHeight
     attrTransfer _ v = do
         return v
     attrConstruct = constructConstraintGuideNatHeight
@@ -750,7 +756,7 @@ constructConstraintGuideNatWidth val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data ConstraintGuideNatWidthPropertyInfo
 instance AttrInfo ConstraintGuideNatWidthPropertyInfo where
-    type AttrAllowedOps ConstraintGuideNatWidthPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps ConstraintGuideNatWidthPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint ConstraintGuideNatWidthPropertyInfo = IsConstraintGuide
     type AttrSetTypeConstraint ConstraintGuideNatWidthPropertyInfo = (~) Int32
     type AttrTransferTypeConstraint ConstraintGuideNatWidthPropertyInfo = (~) Int32
@@ -760,6 +766,7 @@ instance AttrInfo ConstraintGuideNatWidthPropertyInfo where
     type AttrOrigin ConstraintGuideNatWidthPropertyInfo = ConstraintGuide
     attrGet = getConstraintGuideNatWidth
     attrSet = setConstraintGuideNatWidth
+    attrPut = setConstraintGuideNatWidth
     attrTransfer _ v = do
         return v
     attrConstruct = constructConstraintGuideNatWidth
@@ -802,7 +809,7 @@ constructConstraintGuideStrength val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data ConstraintGuideStrengthPropertyInfo
 instance AttrInfo ConstraintGuideStrengthPropertyInfo where
-    type AttrAllowedOps ConstraintGuideStrengthPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps ConstraintGuideStrengthPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint ConstraintGuideStrengthPropertyInfo = IsConstraintGuide
     type AttrSetTypeConstraint ConstraintGuideStrengthPropertyInfo = (~) Gtk.Enums.ConstraintStrength
     type AttrTransferTypeConstraint ConstraintGuideStrengthPropertyInfo = (~) Gtk.Enums.ConstraintStrength
@@ -812,6 +819,7 @@ instance AttrInfo ConstraintGuideStrengthPropertyInfo where
     type AttrOrigin ConstraintGuideStrengthPropertyInfo = ConstraintGuide
     attrGet = getConstraintGuideStrength
     attrSet = setConstraintGuideStrength
+    attrPut = setConstraintGuideStrength
     attrTransfer _ v = do
         return v
     attrConstruct = constructConstraintGuideStrength
