@@ -399,7 +399,7 @@ constructGridLayoutChildColumn val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data GridLayoutChildColumnPropertyInfo
 instance AttrInfo GridLayoutChildColumnPropertyInfo where
-    type AttrAllowedOps GridLayoutChildColumnPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps GridLayoutChildColumnPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint GridLayoutChildColumnPropertyInfo = IsGridLayoutChild
     type AttrSetTypeConstraint GridLayoutChildColumnPropertyInfo = (~) Int32
     type AttrTransferTypeConstraint GridLayoutChildColumnPropertyInfo = (~) Int32
@@ -409,6 +409,7 @@ instance AttrInfo GridLayoutChildColumnPropertyInfo where
     type AttrOrigin GridLayoutChildColumnPropertyInfo = GridLayoutChild
     attrGet = getGridLayoutChildColumn
     attrSet = setGridLayoutChildColumn
+    attrPut = setGridLayoutChildColumn
     attrTransfer _ v = do
         return v
     attrConstruct = constructGridLayoutChildColumn
@@ -451,7 +452,7 @@ constructGridLayoutChildColumnSpan val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data GridLayoutChildColumnSpanPropertyInfo
 instance AttrInfo GridLayoutChildColumnSpanPropertyInfo where
-    type AttrAllowedOps GridLayoutChildColumnSpanPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps GridLayoutChildColumnSpanPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint GridLayoutChildColumnSpanPropertyInfo = IsGridLayoutChild
     type AttrSetTypeConstraint GridLayoutChildColumnSpanPropertyInfo = (~) Int32
     type AttrTransferTypeConstraint GridLayoutChildColumnSpanPropertyInfo = (~) Int32
@@ -461,6 +462,7 @@ instance AttrInfo GridLayoutChildColumnSpanPropertyInfo where
     type AttrOrigin GridLayoutChildColumnSpanPropertyInfo = GridLayoutChild
     attrGet = getGridLayoutChildColumnSpan
     attrSet = setGridLayoutChildColumnSpan
+    attrPut = setGridLayoutChildColumnSpan
     attrTransfer _ v = do
         return v
     attrConstruct = constructGridLayoutChildColumnSpan
@@ -503,7 +505,7 @@ constructGridLayoutChildRow val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data GridLayoutChildRowPropertyInfo
 instance AttrInfo GridLayoutChildRowPropertyInfo where
-    type AttrAllowedOps GridLayoutChildRowPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps GridLayoutChildRowPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint GridLayoutChildRowPropertyInfo = IsGridLayoutChild
     type AttrSetTypeConstraint GridLayoutChildRowPropertyInfo = (~) Int32
     type AttrTransferTypeConstraint GridLayoutChildRowPropertyInfo = (~) Int32
@@ -513,6 +515,7 @@ instance AttrInfo GridLayoutChildRowPropertyInfo where
     type AttrOrigin GridLayoutChildRowPropertyInfo = GridLayoutChild
     attrGet = getGridLayoutChildRow
     attrSet = setGridLayoutChildRow
+    attrPut = setGridLayoutChildRow
     attrTransfer _ v = do
         return v
     attrConstruct = constructGridLayoutChildRow
@@ -555,7 +558,7 @@ constructGridLayoutChildRowSpan val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data GridLayoutChildRowSpanPropertyInfo
 instance AttrInfo GridLayoutChildRowSpanPropertyInfo where
-    type AttrAllowedOps GridLayoutChildRowSpanPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps GridLayoutChildRowSpanPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint GridLayoutChildRowSpanPropertyInfo = IsGridLayoutChild
     type AttrSetTypeConstraint GridLayoutChildRowSpanPropertyInfo = (~) Int32
     type AttrTransferTypeConstraint GridLayoutChildRowSpanPropertyInfo = (~) Int32
@@ -565,6 +568,7 @@ instance AttrInfo GridLayoutChildRowSpanPropertyInfo where
     type AttrOrigin GridLayoutChildRowSpanPropertyInfo = GridLayoutChild
     attrGet = getGridLayoutChildRowSpan
     attrSet = setGridLayoutChildRowSpan
+    attrPut = setGridLayoutChildRowSpan
     attrTransfer _ v = do
         return v
     attrConstruct = constructGridLayoutChildRowSpan
