@@ -546,7 +546,7 @@ constructListItemAccessibleDescription val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data ListItemAccessibleDescriptionPropertyInfo
 instance AttrInfo ListItemAccessibleDescriptionPropertyInfo where
-    type AttrAllowedOps ListItemAccessibleDescriptionPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps ListItemAccessibleDescriptionPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint ListItemAccessibleDescriptionPropertyInfo = IsListItem
     type AttrSetTypeConstraint ListItemAccessibleDescriptionPropertyInfo = (~) T.Text
     type AttrTransferTypeConstraint ListItemAccessibleDescriptionPropertyInfo = (~) T.Text
@@ -556,6 +556,7 @@ instance AttrInfo ListItemAccessibleDescriptionPropertyInfo where
     type AttrOrigin ListItemAccessibleDescriptionPropertyInfo = ListItem
     attrGet = getListItemAccessibleDescription
     attrSet = setListItemAccessibleDescription
+    attrPut = setListItemAccessibleDescription
     attrTransfer _ v = do
         return v
     attrConstruct = constructListItemAccessibleDescription
@@ -598,7 +599,7 @@ constructListItemAccessibleLabel val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data ListItemAccessibleLabelPropertyInfo
 instance AttrInfo ListItemAccessibleLabelPropertyInfo where
-    type AttrAllowedOps ListItemAccessibleLabelPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps ListItemAccessibleLabelPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint ListItemAccessibleLabelPropertyInfo = IsListItem
     type AttrSetTypeConstraint ListItemAccessibleLabelPropertyInfo = (~) T.Text
     type AttrTransferTypeConstraint ListItemAccessibleLabelPropertyInfo = (~) T.Text
@@ -608,6 +609,7 @@ instance AttrInfo ListItemAccessibleLabelPropertyInfo where
     type AttrOrigin ListItemAccessibleLabelPropertyInfo = ListItem
     attrGet = getListItemAccessibleLabel
     attrSet = setListItemAccessibleLabel
+    attrPut = setListItemAccessibleLabel
     attrTransfer _ v = do
         return v
     attrConstruct = constructListItemAccessibleLabel
@@ -650,7 +652,7 @@ constructListItemActivatable val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data ListItemActivatablePropertyInfo
 instance AttrInfo ListItemActivatablePropertyInfo where
-    type AttrAllowedOps ListItemActivatablePropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps ListItemActivatablePropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint ListItemActivatablePropertyInfo = IsListItem
     type AttrSetTypeConstraint ListItemActivatablePropertyInfo = (~) Bool
     type AttrTransferTypeConstraint ListItemActivatablePropertyInfo = (~) Bool
@@ -660,6 +662,7 @@ instance AttrInfo ListItemActivatablePropertyInfo where
     type AttrOrigin ListItemActivatablePropertyInfo = ListItem
     attrGet = getListItemActivatable
     attrSet = setListItemActivatable
+    attrPut = setListItemActivatable
     attrTransfer _ v = do
         return v
     attrConstruct = constructListItemActivatable
@@ -721,6 +724,7 @@ instance AttrInfo ListItemChildPropertyInfo where
     type AttrOrigin ListItemChildPropertyInfo = ListItem
     attrGet = getListItemChild
     attrSet = setListItemChild
+    attrPut = undefined
     attrTransfer _ v = do
         unsafeCastTo Gtk.Widget.Widget v
     attrConstruct = constructListItemChild
@@ -763,7 +767,7 @@ constructListItemFocusable val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data ListItemFocusablePropertyInfo
 instance AttrInfo ListItemFocusablePropertyInfo where
-    type AttrAllowedOps ListItemFocusablePropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps ListItemFocusablePropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint ListItemFocusablePropertyInfo = IsListItem
     type AttrSetTypeConstraint ListItemFocusablePropertyInfo = (~) Bool
     type AttrTransferTypeConstraint ListItemFocusablePropertyInfo = (~) Bool
@@ -773,6 +777,7 @@ instance AttrInfo ListItemFocusablePropertyInfo where
     type AttrOrigin ListItemFocusablePropertyInfo = ListItem
     attrGet = getListItemFocusable
     attrSet = setListItemFocusable
+    attrPut = setListItemFocusable
     attrTransfer _ v = do
         return v
     attrConstruct = constructListItemFocusable
@@ -810,6 +815,7 @@ instance AttrInfo ListItemItemPropertyInfo where
     type AttrOrigin ListItemItemPropertyInfo = ListItem
     attrGet = getListItemItem
     attrSet = undefined
+    attrPut = undefined
     attrTransfer _ = undefined
     attrConstruct = undefined
     attrClear = undefined
@@ -846,6 +852,7 @@ instance AttrInfo ListItemPositionPropertyInfo where
     type AttrOrigin ListItemPositionPropertyInfo = ListItem
     attrGet = getListItemPosition
     attrSet = undefined
+    attrPut = undefined
     attrTransfer _ = undefined
     attrConstruct = undefined
     attrClear = undefined
@@ -887,7 +894,7 @@ constructListItemSelectable val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data ListItemSelectablePropertyInfo
 instance AttrInfo ListItemSelectablePropertyInfo where
-    type AttrAllowedOps ListItemSelectablePropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps ListItemSelectablePropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint ListItemSelectablePropertyInfo = IsListItem
     type AttrSetTypeConstraint ListItemSelectablePropertyInfo = (~) Bool
     type AttrTransferTypeConstraint ListItemSelectablePropertyInfo = (~) Bool
@@ -897,6 +904,7 @@ instance AttrInfo ListItemSelectablePropertyInfo where
     type AttrOrigin ListItemSelectablePropertyInfo = ListItem
     attrGet = getListItemSelectable
     attrSet = setListItemSelectable
+    attrPut = setListItemSelectable
     attrTransfer _ v = do
         return v
     attrConstruct = constructListItemSelectable
@@ -934,6 +942,7 @@ instance AttrInfo ListItemSelectedPropertyInfo where
     type AttrOrigin ListItemSelectedPropertyInfo = ListItem
     attrGet = getListItemSelected
     attrSet = undefined
+    attrPut = undefined
     attrTransfer _ = undefined
     attrConstruct = undefined
     attrClear = undefined
